<?php
/* Copyright (C) 2021      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	    \file       htdocs/tasktoagenda/admin/setup.php
 *		\ingroup    tasktoagenda
 *		\brief      Page to setup tasktoagenda module
 */

// Change this following line to use the correct relative path (../, ../../, etc)
$res=0;
if (! $res && file_exists("../../main.inc.php")) $res=@include '../../main.inc.php';			// to work if your module directory is into a subdir of root htdocs directory
if (! $res && file_exists("../../../main.inc.php")) $res=@include '../../../main.inc.php';		// to work if your module directory is into a subdir of root htdocs directory
if (! $res) die("Include of main fails");
require_once DOL_DOCUMENT_ROOT.'/core/lib/admin.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/ajax.lib.php';
dol_include_once('/tasktoagenda/lib/tasktoagenda.lib.php');

$langs->load("admin");
$langs->load("tasktoagenda@tasktoagenda");
$langs->load("opendsi@tasktoagenda");

if (!$user->admin) accessforbidden();

$action = GETPOST('action', 'aZ09');

/*
 *	Actions
 */

$errors = [];
$error = 0;
$db->begin();

if ($action == 'set_general_options') {
//	$value = GETPOST('KEY', 'int');
//	$res = dolibarr_set_const($db, 'KEY', $value, 'chaine', 0, '', $conf->entity);
//	if (!($res > 0)) {
//		$errors[] = $db->lasterror();
//		$error++;
//	}
} elseif ($action == 'set_notify_options') {
//	$value = GETPOST('KEY', 'int');
//	$res = dolibarr_set_const($db, 'KEY', $value, 'chaine', 0, '', $conf->entity);
//	if (!($res > 0)) {
//		$errors[] = $db->lasterror();
//		$error++;
//	}
} elseif (preg_match('/set_(.*)/', $action, $reg)) {
	$code = $reg[1];
	$value = (GETPOST($code) ? GETPOST($code) : 1);
	$res = dolibarr_set_const($db, $code, $value, 'chaine', 0, '', $conf->entity);
	if ($res < 0) {
		$errors[] = $db->lasterror();
		$error++;
	}
} elseif (preg_match('/del_(.*)/', $action, $reg)) {
	$code = $reg[1];
	$res = dolibarr_del_const($db, $code, $conf->entity);
	if ($res < 0) {
		$errors[] = $db->lasterror();
		$error++;
	}
}

if ($action != '') {
    if (!$error) {
	    $db->commit();
        setEventMessage($langs->trans("SetupSaved"));
	    header("Location: " . $_SERVER["PHP_SELF"]);
        exit;
    } else {
	    $db->rollback();
        setEventMessages('', $errors, 'errors');
    }
}


/*
 *	View
 */

$form = new Form($db);

$wikihelp = '';
llxHeader('', $langs->trans("TaskToAgendaSetup"), $wikihelp);

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("TaskToAgendaSetup"), $linkback, 'title_setup');
print "<br>\n";

$head = tasktoagenda_admin_prepare_head();

dol_fiche_head($head, 'settings', $langs->trans("Module163004Name"), 0, 'opendsi@tasktoagenda');

/**
 * General settings.
 */

print '<div id="general_options"></div>';
print load_fiche_titre($langs->trans("TaskToAgendaGeneralOptions"), '', '');
print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#options">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '<input type="hidden" name="action" value="set_general_options">';

print '<table class="noborder centpercent">';
print '<tr class="liste_titre">';
print '<td class="width20p">' . $langs->trans("Parameters") . '</td>' . "\n";
print '<td>' . $langs->trans("Description") . '</td>' . "\n";
print '<td class="right">' . $langs->trans("Value") . '</td>' . "\n";
print "</tr>\n";

// TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaAddButtonCreateEventOnTaskName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaAddButtonCreateEventOnTaskDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK');
} else {
	if (empty($conf->global->TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK#general_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK#general_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

print '</table>' . "\n";

//print '<br>';
//print '<div align="center">';
//print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
//print '</div>';

print '</form>';
print '<br>';

/**
 * Notification settings.
 */

print '<div id="notify_options"></div>';
print load_fiche_titre($langs->trans("TaskToAgendaNotifyOptions"), '', '');
print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#options">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '<input type="hidden" name="action" value="set_notify_options">';

print '<table class="noborder centpercent">';
print '<tr class="liste_titre">';
print '<td class="width20p">' . $langs->trans("Parameters") . '</td>' . "\n";
print '<td>' . $langs->trans("Description") . '</td>' . "\n";
print '<td class="right">' . $langs->trans("Value") . '</td>' . "\n";
print "</tr>\n";

// TASKTOAGENDA_NOTIFY_BY_EMAIL_MANDATORY
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailMandatoryName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailMandatoryDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_NOTIFY_BY_EMAIL_MANDATORY');
} else {
	if (empty($conf->global->TASKTOAGENDA_NOTIFY_BY_EMAIL_MANDATORY)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_NOTIFY_BY_EMAIL_MANDATORY#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_NOTIFY_BY_EMAIL_MANDATORY#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

// TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_CREATE
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenCreateName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenCreateDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_CREATE');
} else {
	if (empty($conf->global->TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_CREATE)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_CREATE#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_CREATE#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

// TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DATES_UPDATED
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenDatesUpdatedName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenDatesUpdatedDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DATES_UPDATED');
} else {
	if (empty($conf->global->TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DATES_UPDATED)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DATES_UPDATED#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DATES_UPDATED#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

// TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_PROGRESS_UPDATED
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenProgressUpdatedName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenProgressUpdatedDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_PROGRESS_UPDATED');
} else {
	if (empty($conf->global->TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_PROGRESS_UPDATED)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_PROGRESS_UPDATED#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_PROGRESS_UPDATED#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

// TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DESCRIPTION_UPDATED
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenDescriptionUpdatedName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenDescriptionUpdatedDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DESCRIPTION_UPDATED');
} else {
	if (empty($conf->global->TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DESCRIPTION_UPDATED)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DESCRIPTION_UPDATED#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DESCRIPTION_UPDATED#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

// TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DELETE
print '<tr class="oddeven">' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenDeleteName") . '</td>' . "\n";
print '<td>' . $langs->trans("TaskToAgendaNotifyByEmailWhenDeleteDesc") . '</td>' . "\n";
print '<td class="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
	print ajax_constantonoff('TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DELETE');
} else {
	if (empty($conf->global->TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DELETE)) {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DELETE#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
	} else {
		print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_TASKTOAGENDA_NOTIFY_BY_EMAIL_WHEN_DELETE#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
	}
}
print '</td></tr>' . "\n";

print '</table>' . "\n";

//print '<br>';
//print '<div align="center">';
//print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
//print '</div>';

print '</form>';

dol_fiche_end();

llxFooter();

$db->close();
