<?php
/* Copyright (C) 2021      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */


class ActionsTaskToAgenda
{
	/**
	 * @var DoliDB Database handler.
	 */
	public $db;
	/**
	 * @var string Error
	 */
	public $error = '';
	/**
	 * @var array Errors
	 */
	public $errors = array();

	/**
	 * @var array Hook results. Propagated to $hookmanager->resArray for later reuse
	 */
	public $results = array();

	/**
	 * @var string String displayed by executeHook() immediately after return
	 */
	public $resprints;

	/**
	 * Constructor
	 *
	 * @param        DoliDB $_db Database handler
	 */
	public function __construct($_db)
	{
		global $db;
		$this->db = is_object($_db) ? $_db : $db;
	}

	/**
	 * Overloading the updateSession function : replacing the parent's function with the one below
	 *
	 * @param   array() $parameters Hook metadatas (context, etc...)
	 * @param   CommonObject &$object The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param   string &$action Current action (if set). Generally create or edit or null
	 * @param   HookManager $hookmanager Hook manager propagated to allow calling another hook
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	function updateSession($parameters, &$object, &$action, $hookmanager)
	{
		global $langs;
		if (is_object($langs)) $langs->load('tasktoagenda@tasktoagenda');
		return 0;
	}

	/**
	 * Overloading the afterLogin function : replacing the parent's function with the one below
	 *
	 * @param   array() $parameters Hook metadatas (context, etc...)
	 * @param   CommonObject &$object The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param   string &$action Current action (if set). Generally create or edit or null
	 * @param   HookManager $hookmanager Hook manager propagated to allow calling another hook
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	function afterLogin($parameters, &$object, &$action, $hookmanager)
	{
		global $langs;
		if (is_object($langs)) $langs->load('tasktoagenda@tasktoagenda');
		return 0;
	}

	/**
	 * Overloading the doActions function : replacing the parent's function with the one below
	 *
	 * @param	array()			$parameters		Hook metadatas (context, etc...)
	 * @param	CommonObject	&$object		The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param	string			&$action		Current action (if set). Generally create or edit or null
	 * @param	HookManager		$hookmanager	Hook manager propagated to allow calling another hook
	 * @return	int								< 0 on error, 0 on success, 1 to replace standard code
	 */
	function doActions($parameters, &$object, &$action, $hookmanager)
	{
		global $langs, $user, $conf;

		$context = explode(':', $parameters['context']);

		if (!empty($conf->global->TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK) && in_array('projecttaskcard', $context)) {
			if ($action == 'tta_create_event') {
				$id = GETPOST('id', 'int');
				$result = $object->fetch($id);
				if ($result < 0) {
					setEventMessages($object->error, $object->errors, 'errors');
					return -1;
				} elseif ($result == 0) {
					$langs->load('errors');
					$this->error = $langs->trans('ErrorRecordNotFound') . " (Task ID: {$id})";
					return -1;
				}

				$project = new Project($this->db);
				$result = $project->fetch($object->fk_project);
				if ($result < 0) {
					setEventMessages($project->error, $project->errors, 'errors');
					return -1;
				} elseif ($result == 0) {
					$langs->load('errors');
					$this->error = $langs->trans('ErrorRecordNotFound') . " (Project ID: {$object->fk_project})";
					return -1;
				}

				// Users assigned
				$result = $object->liste_contact(-1, 'internal');
				if (!is_array($result)) {
					setEventMessages($object->error, $object->errors, 'errors');
					return -1;
				}
				$users_assigned = array($user->id => array(
					'id' => $user->id,
					'transparency' => 0,
					'answer_status' => 0,
					'mandatory' => 0
				));
				foreach ($result as $infos) {
					$users_assigned[$infos['id']] = array(
						'id' => $infos['id'],
						'transparency' => 0,
						'answer_status' => 0,
						'mandatory' => 0
					);
				}
				$_SESSION['assignedtouser'] = json_encode($users_assigned);

				// Contacts assigned
				$result = $object->liste_contact(-1, 'external');
				if (!is_array($result)) {
					setEventMessages($object->error, $object->errors, 'errors');
					return -1;
				}
				$contacts_assigned = array();
				foreach ($result as $infos) {
					$contacts_assigned[$infos['id']] = $infos['id'];
				}

				$date_start_infos = dol_getdate($object->date_start);
				$date_end_infos = dol_getdate($object->date_end);

				dol_include_once('/tasktoagenda/class/tasktoagenda.class.php');
				$create_params = array(
					'action' => 'create',
					'label' => $object->ref . ' - ' . $object->label,
					'apmin' => $date_start_infos['minutes'],
					'aphour' => $date_start_infos['hours'],
					'apday' => $date_start_infos['mday'],
					'apmonth' => $date_start_infos['mon'],
					'apyear' => $date_start_infos['year'],
					'p2min' => $date_end_infos['minutes'],
					'p2hour' => $date_end_infos['hours'],
					'p2day' => $date_end_infos['mday'],
					'p2month' => $date_end_infos['mon'],
					'p2year' => $date_end_infos['year'],
					'percentage' => $object->progress,
					'note' => $object->description,
					'originid' => $object->id,
					'origin' => TaskToAgenda::EVENT_ELEMENT_TYPE,
					'socid' => $project->socid,
					'projectid' => $object->fk_project,
					'projecttaskid' => $object->id,
					'donotclearsession' => 1,
					'socpeopleassigned' => array_values($contacts_assigned),
					'backtopage' => dol_buildpath('/projet/tasks/task.php', 1) . '?id=' . $object->id . '&withproject=' . $object->fk_project,
				);

				header('Location: ' . DOL_URL_ROOT . '/comm/action/card.php?' . http_build_query($create_params));
				exit();
			}
		} elseif (in_array('actioncard', $context)) {
			if ($action == "classin") {
				$id = GETPOST('id', 'int');
				$result = $object->fetch($id);
				if ($result < 0) {
					setEventMessages($object->error, $object->errors, 'errors');
					return -1;
				} elseif ($result == 0) {
					$langs->load('errors');
					$this->error = $langs->trans('ErrorRecordNotFound') . " (Event ID: {$id})";
					return -1;
				}

				dol_include_once('/tasktoagenda/class/tasktoagenda.class.php');
				if ($object->type_id == TaskToAgenda::EVENT_TYPE_ID) {
					$langs->load('tasktoagenda@tasktoagenda');
					setEventMessage($langs->trans('TaskToAgendaErrorCannotModifyProjectEventLinkType'), 'errors');
					return -1;
				}
			}
		}

		return 0;
	}

	/**
	 * Overloading the addMoreActionsButtons function : replacing the parent's function with the one below
	 *
	 * @param	array()			$parameters		Hook metadatas (context, etc...)
	 * @param	CommonObject	&$object		The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param	string			&$action		Current action (if set). Generally create or edit or null
	 * @param	HookManager		$hookmanager	Hook manager propagated to allow calling another hook
	 * @return	int								< 0 on error, 0 on success, 1 to replace standard code
	 */
	function addMoreActionsButtons($parameters, &$object, &$action, $hookmanager)
	{
		global $conf, $langs;

		$context = explode(':', $parameters['context']);

		if (!empty($conf->global->TASKTOAGENDA_ADD_BUTTON_CREATE_EVENT_ON_TASK) && in_array('projecttaskcard', $context)) {
			$langs->load('agenda');
			print '<a class="butAction" href="' . $_SERVER['PHP_SELF'] . '?action=tta_create_event&id=' . $object->id . (GETPOSTISSET('withproject') ? '&withproject=' . $object->fk_project : '') . '">' . $langs->trans('AddEvent') . '</a>';
		}

		return 0;
	}
}