<?php
/*  Copyright (C) 2021      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	\file       htdocs/tasktoagenda/core/triggers/interface_99_modTaskToAgenda_TaskToAgenda.class.php
 *  \ingroup    tasktoagenda
 *	\brief      File of class of triggers for TaskToAgenda module
 */


require_once DOL_DOCUMENT_ROOT.'/core/triggers/dolibarrtriggers.class.php';


/**
 *  Class of triggers for TaskToAgenda module
 */
class InterfaceTaskToAgenda extends DolibarrTriggers
{
	public $family = 'tasktoagenda';
	public $description = "Triggers of this module catch triggers event for TaskToAgenda module.";
	public $version = self::VERSION_DOLIBARR;
	public $picto = 'technic';


	/**
	 * Function called when a Dolibarrr business event is done.
	 * All functions "runTrigger" are triggered if file is inside directory htdocs/core/triggers or htdocs/module/code/triggers (and declared)
	 *
	 * @param string		$action		Event action code
	 * @param Object		$object     Object
	 * @param User		    $user       Object user
	 * @param Translate 	$langs      Object langs
	 * @param conf		    $conf       Object conf
	 * @return int         				<0 if KO, 0 if no triggered ran, >0 if OK
	 */
	public function runTrigger($action, $object, User $user, Translate $langs, Conf $conf)
	{
		if (empty($conf->tasktoagenda->enabled)) return 0;     // Module not active, we do nothing

		if (!empty($object->context['tta_processing'])) return 0;

		switch ($action) {
			case 'TASK_CREATE':
			case 'PROJECT_TASK_DELETE_CONTACT':
			case 'PROJECT_TASK_ADD_CONTACT':
			case 'TASK_MODIFY':
			case 'TASK_DELETE':
			case 'TASK_TIMESPENT_CREATE':
			case 'TASK_TIMESPENT_MODIFY':
			case 'ACTION_MODIFY':
				dol_syslog("Trigger '" . $this->name . "' for action '$action' launched by " . __FILE__ . ". id=" . $object->id);

				dol_include_once('/tasktoagenda/class/tasktoagenda.class.php');
				$tasktoagenda = new TaskToAgenda($this->db);

				if ($action == 'TASK_CREATE') $result = $tasktoagenda->createEventFromTask($user, $object->id);
				elseif ($action == 'TASK_DELETE') $result = $tasktoagenda->deleteEventFromTask($user, $object);
				elseif ($action == 'ACTION_MODIFY') $result = $tasktoagenda->updateTaskFromEvent($user, $object);
				else $result = $tasktoagenda->updateEventFromTask($user, $object, $action == 'TASK_TIMESPENT_CREATE' || $action == 'TASK_TIMESPENT_MODIFY');
				if (!empty($tasktoagenda->successes)) setEventMessages(null, $tasktoagenda->successes);
				if (!empty($tasktoagenda->error) || !empty($tasktoagenda->errors)) setEventMessages($tasktoagenda->error, $tasktoagenda->errors, 'errors');
				if ($result < 0) {
					return -1;
				}
				break;
			case 'ACTION_CREATE':
			case 'ACTION_DELETE_CONTACT':
			case 'ACTION_ADD_CONTACT':
			case 'ACTION_DELETE':
				dol_syslog("Trigger '" . $this->name . "' for action '$action' launched by " . __FILE__ . ". id=" . $object->id);

				dol_include_once('/tasktoagenda/class/tasktoagenda.class.php');
				if ($object->type_id == TaskToAgenda::EVENT_TYPE_ID) {
					if ($action == 'ACTION_CREATE')
						$this->error = $langs->trans('TaskToAgendaErrorCannotCreateEventLinkType');
					elseif ($action == 'ACTION_DELETE')
						$this->error = $langs->trans('TaskToAgendaErrorCannotDeleteEventLinkType');
					else
						$this->error = $langs->trans('TaskToAgendaErrorCannotModifyContactsEventLinkType');
					return -1;
				}
				break;
		}

		return 0;
	}
}